@@ -1,4 +1,4 @@
-__version__ = "0.3.6"
+__version__ = "0.3.7"
 
 __release_notes__ = {
     # "0.1.6": {
@@ -21,16 +21,15 @@ __release_notes__ = {
     #
     #        ],
     #    },
-    "0.3.6": {
+    "0.3.7": {
         "STATUS": [
         ],
         "A2P2": [
         ],
         "VLTI": [
-            "Disable SEQ.RELOFF.X for GRAVITY dual to make OB compliant"
+            "Revert SEQ.RELOFF.X/Y = 0.0 (same as default) for GRAVITY dual_obs_exp template"
         ],
         "CHARA": [
-
         ],
         "TODO-SCIENCE": [
             "Check DIT table from last template user manuals",
@@ -46,6 +45,21 @@ __release_notes__ = {
             "Complete test suite with real p2 submission",
             "Try to read OB in P2 and send them back to Aspro2 as a new obs",
         ],
+    },"0.3.6": {
+        "STATUS": [
+        ],
+        "A2P2": [
+        ],
+        "VLTI": [
+            "Disable SEQ.RELOFF.X for GRAVITY dual to make OB compliant"
+        ],
+        "CHARA": [
+
+        ],
+        "TODO-SCIENCE": [
+        ],
+        "TODO-DEV": [
+        ],
     },"0.3.5": {
         "STATUS": [
         ],
